import rosbag2_py._storage

class Info:
    def __init__(self) -> None: ...
    def read_metadata(self, arg0: str, arg1: str) -> rosbag2_py._storage.BagMetadata: ...
    def read_metadata_and_output_service_verbose(self, arg0: str, arg1: str) -> None: ...
